function Slider(x, y, window) {
  var sWidth = 0;
  var xCoord = x;
  var yCoord = y;
  var shell;
  var onMouseMove;
  var onMouseUp;
  var max = 200;
  var min = 0;
  var stepR = 1;
  
  // Component Variables
  var barT;
  var barB;
  var capL;
  var capR;
  var tip;
  var ticks = new Array();
  var ticksV = new Array();
  var labels = new Array();
  var labelsV = new Array();
  var labelsS = 10;
  
  // Color
  var labelsC = "#000000";
  
  // Public functions
  this.handleMouseMove = handleMouseMove;
  this.numberTicks = numberTicks;
  this.valueTicks = valueTicks;
  this.setWidth = setWidth;
  this.setCoords = setCoords;
  this.setValue = setValue;
  this.setOnMouseMove = setOnMouseMove;
  this.setOnMouseUp = setOnMouseUp;
  this.setMax = setMax;
  this.setMin = setMin;  
  this.setRange = setRange;
  this.setTicks = setTicks;
  this.setLabels = setLabels;
  this.setLabelColor = setLabelColor;
  this.setLabelSize = setLabelSize;
  this.getCoords = getCoords;
  this.getValue = getValue;  
  
  // Initialize slider 
  shell = window;
  sWidth = max;
  setCoords(x, y);
  placeSlider();
  
  // Create and place components
  function placeSlider() { 
    // Upper Bar
    barT = new Image();
    barT.src = "Resources/bar.png";
    barT.width = sWidth;
    barT.height = 1;
    barT.hOffset = xCoord;
    barT.vOffset = yCoord;
    barT.window = shell;
    
    // Lower Bar
    barB = new Image();
    barB.src = "Resources/bar.png";
    barB.width = sWidth;
    barB.height = 1;
    barB.hOffset = xCoord;
    barB.vOffset = yCoord + 2;
    barB.window = shell;
    
    // Left Cap
    capL = new Image();
    capL.src = "Resources/bar.png";
    capL.width = 3;
    capL.height = 1;
    capL.hRegistrationPoint = 2;
    capL.hOffset = xCoord;
    capL.vOffset = yCoord + 2;
    capL.rotation = 90;
    capL.window = shell;
    
    // Right Cap
    capR = new Image();
    capR.src = "Resources/bar.png";
    capR.width = 3;
    capR.height = 1;
    capR.hRegistrationPoint = 2;
    capR.hOffset = sWidth + xCoord;
    capR.vOffset = yCoord + 2;
    capR.rotation = 90;
    capR.window = shell;
    
    // Place Tip
    tip = new Image();
    tip.src = "Resources/tip.png";
    tip.width = 10;
    tip.height = 18;
    tip.hRegistrationPoint = 5;
    tip.hOffset = ((sWidth + xCoord) / 2) + xCoord;
    tip.vOffset = yCoord - 9;
    tip.onMouseMove = handleMouseMove;
    tip.onMouseUp = handleMouseUp;
    tip.window = shell;   
    
    setValue(Math.round((max - min) / 2));
  }
  
  // Handles the horiztonal moving of the slider tip
  function handleMouseMove() {
    var value;  
    var lBound = xCoord;
    var rBound = (sWidth + xCoord);
    if(system.event.hOffset < lBound) {
      tip.hOffset = lBound;
      value = min;   
    } else if(system.event.hOffset > rBound) {
      tip.hOffset = rBound; 
      value = max;   
    } else {
      tip.hOffset = system.event.hOffset;
      value = getValue();
    }
    if(onMouseMove != undefined) {
      onMouseMove(value);
    }    
  }
  
  function handleMouseUp() {
    if(onMouseUp != undefined) {
      onMouseUp(getValue());
    }
  }    
  
  function clear() {
    setTicks(0);
    setLabels("");
  }
  
  function numberTicks() {
    var strings = new Array();
    for(i = 0; i < ticks.length; i++) {
      strings[i] = new String(i);
    }
    setLabels(strings.toString());
  }
  
  function valueTicks() {
    var strings = new Array(); 
    if(ticks.length > 0) {
      var spread = (max - min) / (ticks.length - 1);
      for(i = 0; i < ticks.length; i++) {
        strings[i] = new String(min + (i * spread));
      }
      setLabels(strings.toString());
    }
  }
  
  /************************** Sets and Gets ***********************/
  function setWidth(width) {
    if(width > shell.width) {
      alert("Your Slider width exceeds your window!");
    } else if(sWidth != 0) {
      sWidth = width;
      barT.width = sWidth;
      barB.width = sWidth;
      capR.hOffset = sWidth + xCoord; 
      placeSlider();
      setTicks(ticksV.toString());
      setLabels(labelsV.toString());
    }
  }
  
  function setCoords(x, y) {
    xCoord = x;
    yCoord = y;
  }
  
  function setValue(value) {
    if(value <= min) {
      tip.hOffset = xCoord;
    } else if(value >= max) {
      tip.hOffset = sWidth + xCoord;
    } else {
      var nValue = Math.abs((value - min)) * (sWidth / (max- min));
      tip.hOffset = nValue + xCoord;
    }
    try {
      if(onMouseMove != undefined) {
        onMouseMove(value);
      }
      if(onMouseUp != undefined) {
        onMouseUp(value);
      }
    } catch(e) {}
  }
  
  function setOnMouseMove(funct) {
    onMouseMove = funct;
  }
  
  function setOnMouseUp(funct) {
    onMouseUp = funct;
  }
  
  function setMax(value) {
    max = value;  
  }
  
  function setMin(value) {
    min = value;
  }
  
  function setRange(values) {
    var nValues = values.split(",");
    min = parseInt(nValues[0]);
    max = parseInt(nValues[1]);
  }
  
  function setTicks(num) {
    if(num == 0) {
      for(i = 0; i < ticks.length; i++) {
        delete ticks[i];
      }
    } else {
      ticks = new Array();
      ticksV = new Array();      
      var space = Math.round(sWidth / (num - 1));
      for(i = 0; i < num; i++) {
        ticks[i] = new Image();
        ticks[i].src = "Resources/bar.png";
        ticks[i].width = 3;
        ticks[i].height = 1;
        ticks[i].hRegistrationPoint = 2;
        ticks[i].rotation = 90;
        ticks[i].hOffset = xCoord + (space * i);
        ticks[i].vOffset = yCoord + 8;
        ticks[i].window = shell; 
        ticksV[i] = ticks[i].data;        
      }
      setValue(getValue());
    }
  }
  
  function setLabels(sLabels) {
    if(sLabels == "") {
      for(i = 0; i < labels.length; i++) {
        delete labels[i];
      }
    } else {
      labels = new Array();
      labelsV = new Array();
      var strings = sLabels.split(",");
      var space = Math.round(sWidth / (strings.length - 1));
      for(i = 0; i < strings.length; i++) {
        labels[i] = new Text();
        labels[i].font = "Arial";
        labels[i].data = strings[i];
        labels[i].hAlign = "center";
        labels[i].size = labelsS;
        labels[i].vOffset = yCoord + 20 + Math.abs(labelsS - 10);
        labels[i].hOffset = xCoord + (space * i) - 1;
        labels[i].color = labelsC;
        labels[i].window = shell;
        labelsV[i] = labels[i].data;
      }
      setValue(getValue());
    }
  }
  
  function setLabelColor(hex) {
    labelsC = hex;
    setLabels(labelsV.toString());
  }
  
  function setLabelSize(size) {
    labelsS = size;
    setLabels(labelsV.toString());
  }
  
  function getCoords() {
    var coords = new Array();
    coords[0] = xCoord;
    coords[1] = yCoord;
    return coords;
  }
  
  function getValue() {
    var value = Math.round((tip.hOffset - xCoord) * ((max - min) / sWidth)) + min;   
    return value;
  }
}
